action_runner — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# action_runner

class `camelot.view.action_runner.` `ActionRunner`(generator_function, gui_context)

  Helper class for handling the signals and slots when an action is running. This class takes a generator and iterates it within the model thread while taking care of Exceptions raised and ActionSteps yielded by the generator.

  This is class is intended for internal Camelot use only.

  `exception`(exception_info)

    Handle an exception raised by the generator

  `exec_`(flags=0)

    Reimplementation of exec_ to prevent the event loop being started when exit has been called prior to calling exec_.

    This can be the case when running in single threaded mode.

  `exit`(return_code=0)

    Reimplementation of exit to store the return code

  `generator`(generator)

    Handle the creation of the generator

  `next`(yielded)

    Handle the result of the next call of the generator

    Parameters: | yielded – the object that was yielded by the generator in the model thread

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus